The mvmlib API reference
========================

.. automodule:: mvm
   :noindex:

The “DOELib” module
-------------------

.. automodule:: mvm.DOELib
   :members:

.. autoclass:: mvm.DOELib.Design
   :members:

The “fuzzyLib” module
---------------------

.. automodule:: mvm.fuzzyLib
   :members:

.. autoclass:: mvm.fuzzyLib.TriangularFunc
   :members:

.. autoclass:: mvm.fuzzyLib.FuzzyRule
   :members:

.. autoclass:: mvm.fuzzyLib.FuzzySet
   :members:

.. autoclass:: mvm.fuzzyLib.FuzzySystem
   :members:

The “uncertaintyLib” module
---------------------------

.. automodule:: mvm.uncertaintyLib
   :members:

.. autoclass:: mvm.uncertaintyLib.GaussianFunc
   :members:

.. autoclass:: mvm.uncertaintyLib.Distribution
   :members:

.. autoclass:: mvm.uncertaintyLib.VisualizeDist
   :members:

The "designMargins" module
--------------------------

.. automodule:: mvm.designMarginsLib
   :members:

.. autoclass:: mvm.designMarginsLib.ScalarParam
   :members:
   :noindex:
   :undoc-members:
   :show-inheritance:

.. autoclass:: mvm.designMarginsLib.VectorParam
   :members:
   :noindex:
   :undoc-members:
   :show-inheritance:

.. autoclass:: mvm.designMarginsLib.MatrixParam
   :members:
   :noindex:
   :undoc-members:
   :show-inheritance:

.. autoclass:: mvm.designMarginsLib.FixedParam
   :members:

.. autoclass:: mvm.designMarginsLib.DesignParam
   :members:

.. autoclass:: mvm.designMarginsLib.InputSpec
   :members:
   :noindex:
   :undoc-members:
   :show-inheritance:

.. autoclass:: mvm.designMarginsLib.Behaviour
   :members:
   :noindex:

.. autoclass:: mvm.designMarginsLib.Performance
   :members:
   :noindex:
   :undoc-members:
   :show-inheritance:

.. autoclass:: mvm.designMarginsLib.MarginNode
   :members:

.. autoclass:: mvm.designMarginsLib.MarginNetwork
   :members:
   :noindex: